@@ -39,6 +39,10 @@ class Account(Entity):
     pass
 
 
+class AccountConfigurations(Entity):
+    pass
+
+
 class Asset(Entity):
     pass
 
@@ -51,6 +55,10 @@ class Position(Entity):
     pass
 
 
+class AccountActivity(Entity):
+    pass
+
+
 class Bar(Entity):
     def __getattr__(self, key):
         if key == 't':
