@@ -1,3 +1,3 @@
 from .rest import REST  # noqa
 from .stream import Stream  # noqa
-from .stream2 import StreamConn # noqa
+from .streamconn import StreamConn # noqa
