@@ -10,8 +10,8 @@ from .common import (
     get_api_version,
 )
 from .entity import (
-    Account, Asset, Order, Position,
-    BarSet, Clock, Calendar,
+    Account, AccountConfigurations, AccountActivity,
+    Asset, Order, Position, BarSet, Clock, Calendar,
 )
 from . import polygon
 
@@ -59,9 +59,11 @@ class REST(object):
         key_id=None,
         secret_key=None,
         base_url=None,
-        api_version=None
+        api_version=None,
+        oauth=None
     ):
-        self._key_id, self._secret_key = get_credentials(key_id, secret_key)
+        self._key_id, self._secret_key, self._oauth = get_credentials(
+            key_id, secret_key, oauth)
         self._base_url = base_url or get_base_url()
         self._api_version = get_api_version(api_version)
         self._session = requests.Session()
@@ -83,10 +85,12 @@ class REST(object):
         base_url = base_url or self._base_url
         version = api_version if api_version else self._api_version
         url = base_url + '/' + version + path
-        headers = {
-            'APCA-API-KEY-ID': self._key_id,
-            'APCA-API-SECRET-KEY': self._secret_key,
-        }
+        headers = {}
+        if self._oauth:
+            headers['Authorization'] = 'Bearer ' + self._oauth
+        else:
+            headers['APCA-API-KEY-ID'] = self._key_id
+            headers['APCA-API-SECRET-KEY'] = self._secret_key
         opts = {
             'headers': headers,
             # Since we allow users to set endpoint URL via env var,
@@ -147,6 +151,9 @@ class REST(object):
     def post(self, path, data=None):
         return self._request('POST', path, data)
 
+    def patch(self, path, data=None):
+        return self._request('PATCH', path, data)
+
     def delete(self, path, data=None):
         return self._request('DELETE', path, data)
 
@@ -161,6 +168,31 @@ class REST(object):
         resp = self.get('/account')
         return Account(resp)
 
+    def get_account_configurations(self):
+        '''Get account configs'''
+        resp = self.get('/account/configurations')
+        return AccountConfigurations(resp)
+
+    def update_account_configurations(
+        self,
+        no_shorting=None,
+        dtbp_check=None,
+        trade_confirm_email=None,
+        suspend_trade=None
+    ):
+        '''Update account configs'''
+        params = {}
+        if no_shorting is not None:
+            params['no_shorting'] = no_shorting
+        if dtbp_check is not None:
+            params['dtbp_check'] = dtbp_check
+        if trade_confirm_email is not None:
+            params['trade_confirm_email'] = trade_confirm_email
+        if suspend_trade is not None:
+            params['suspend_trade'] = suspend_trade
+        resp = self.patch('/account/configurations', params)
+        return AccountConfigurations(resp)
+
     def list_orders(self, status=None, limit=None, after=None, until=None,
                     direction=None, params=None):
         '''
@@ -216,10 +248,37 @@ class REST(object):
         resp = self.get('/orders/{}'.format(order_id))
         return Order(resp)
 
+    def replace_order(
+        self,
+        order_id,
+        qty=None,
+        limit_price=None,
+        stop_price=None,
+        time_in_force=None,
+        client_order_id=None
+    ):
+        params = {}
+        if qty is not None:
+            params['qty'] = qty
+        if limit_price is not None:
+            params['limit_price'] = limit_price
+        if stop_price is not None:
+            params['stop_price'] = stop_price
+        if time_in_force is not None:
+            params['time_in_force'] = time_in_force
+        if client_order_id is not None:
+            params['client_order_id'] = client_order_id
+        resp = self.patch('/orders/{}'.format(order_id), params)
+        return Order(resp)
+
     def cancel_order(self, order_id):
         '''Cancel an order'''
         self.delete('/orders/{}'.format(order_id))
 
+    def cancel_all_orders(self):
+        '''Cancel all open orders'''
+        self.delete('/orders')
+
     def list_positions(self):
         '''Get a list of open positions'''
         resp = self.get('/positions')
@@ -230,11 +289,19 @@ class REST(object):
         resp = self.get('/positions/{}'.format(symbol))
         return Position(resp)
 
+    def close_position(self, symbol):
+        '''Liquidates the position for the given symbol at market price'''
+        self.delete('/positions/{}'.format(symbol))
+
+    def close_all_positions(self):
+        '''Liquidates all open positions at market price'''
+        self.delete('/positions')
+
     def list_assets(self, status=None, asset_class=None):
         '''Get a list of assets'''
         params = {
             'status': status,
-            'assert_class': asset_class,
+            'asset_class': asset_class,
         }
         resp = self.get('/assets', params)
         return [Asset(o) for o in resp]
@@ -279,6 +346,34 @@ class REST(object):
         resp = self.get('/clock')
         return Clock(resp)
 
+    def get_activities(
+        self,
+        activity_types=None,
+        until=None,
+        after=None,
+        direction=None,
+        date=None,
+        page_size=None,
+    ):
+        url = '/account/activities'
+        params = {}
+        if isinstance(activity_types, list):
+            params['activity_types'] = ','.join(activity_types)
+        elif activity_types is not None:
+            url += '/{}'.format(activity_types)
+        if after is not None:
+            params['after'] = after
+        if until is not None:
+            params['until'] = until
+        if direction is not None:
+            params['direction'] = direction
+        if date is not None:
+            params['date'] = date
+        if page_size is not None:
+            params['page_size'] = page_size
+        resp = self.get(url, data=params)
+        return [AccountActivity(o) for o in resp]
+
     def get_calendar(self, start=None, end=None):
         params = {}
         if start is not None:
